# FILMOPTICS

Filmoptics is a GUI application for optical calculations on multilayer thin films. It is built around the Transfer-Matrix Method, through the [tmm](https://pypi.org/project/tmm/) package.